@@ -218,7 +218,7 @@ class BaroboCtx():
   CMD_SMOOTHMOVE = 0x80
   CMD_SETMOTORSTATES = 0x81
   CMD_SETGLOBALACCEL = 0x82
-  CMD_PING = 0x83
+  CMD_PING = 0x89
 
   MOTOR_FORWARD = 1
   MOTOR_BACKWARD = 2
@@ -302,6 +302,19 @@ class BaroboCtx():
     except:
       raise BaroboException('Could not connect to Bluetooth at {0}'.format(macaddr))
 
+  def connectMobotBluetooth(self, macaddr):
+    """
+    Connect the BaroboContext to a Bluetooth Mobot or legacy Bluetooth Linkbot.
+    """
+    self.phys = _comms.PhysicalLayer_Bluetooth(macaddr)
+    self.link = _comms.LinkLayer_Socket(self.phys, self.handlePacket)
+    self.link.start()
+    try:
+      self.__init_comms()
+    except:
+      raise BaroboException('Could not connect to Bluetooth at {0}'.format(macaddr))
+
+
   def connectDongleTTY(self, ttyfilename):
     """
     Connect the BaroboCtx to a Linkbot that is connected with a USB cable.
@@ -316,6 +329,20 @@ class BaroboCtx():
     except:
       raise BaroboException('Could not connect to dongle at {0}'.format(ttyfilename))
 
+  def connectDongleSFP(self, ttyfilename):
+    """
+    Connect the BaroboCtx to a Linkbot using libsfp that is connected with a USB cable.
+    """
+    self.phys = _comms.PhysicalLayer_TTY(ttyfilename)
+    self.link = _comms.LinkLayer_SFP(self.phys, self.handlePacket)
+    self.link.start()
+    try:
+      self.__init_comms()
+      self.__checkStatus()
+      self.__getDongleID()
+    except:
+      raise BaroboException('Could not connect to dongle at {0}'.format(ttyfilename))
+
   def disconnect(self):
     self.phys.disconnect()
 
@@ -329,7 +356,7 @@ class BaroboCtx():
   def getScannedRobots(self):
     return self.scannedIDs
 
-  def getLinkbot(self, serialID=None):
+  def getLinkbot(self, serialID=None, linkbotClass=None):
     if serialID is None:
       self.giant_lock.acquire()
       serialID = list(self.scannedIDs.keys())[0]
@@ -338,7 +365,9 @@ class BaroboCtx():
     if serialID not in self.scannedIDs:
       self.findRobot(serialID)
       self.waitForRobot(serialID)
-    l = Linkbot()
+    if linkbotClass is None:
+      linkbotClass = Linkbot
+    l = linkbotClass()
     l.zigbeeAddr = self.scannedIDs[serialID]
     l.serialID = serialID
     l.baroboCtx = self
